@@ -9,11 +9,11 @@ class User:
 Database.register()
 
 if __name__ == '__main__':
-    db = Database('sqlite://')
+    db = Database('sqlite://') # database urls: http://docs.sqlalchemy.org/en/latest/core/engines.html#database-urls
     db.create_tables()
-    
+
     user = User(name = 'Hello World')
     db.session.add_then_commit(user)
-    
+
     user = db.session.query(User).get(1)
-    print 'My name is', user.name
+    print 'My name is', user.name
\ No newline at end of file
